@@ -7,7 +7,7 @@
 #include <WINGs/WUtil.h>
 #include <X11/Xlib.h>
 
-#define WINGS_H_VERSION  20010117
+#define WINGS_H_VERSION  20020104
 
 
 #ifdef __cplusplus
@@ -37,7 +37,8 @@ typedef struct {
 } WMRect;
 
 
-/* WMRange was moved in WUtil.h */
+
+
 
 #define ClientMessageMask	(1L<<30)
 
@@ -384,6 +385,7 @@ typedef struct WMListItem {
 typedef struct WMAlertPanel {
     WMWindow *win;		       /* window */
     WMBox *vbox;
+    WMBox *hbox;
     WMButton *defBtn;		       /* default button */
     WMButton *altBtn;		       /* alternative button */
     WMButton *othBtn;		       /* other button */
@@ -392,13 +394,30 @@ typedef struct WMAlertPanel {
     WMLabel *mLbl;		       /* message label */
     WMFrame *line;		       /* separator */
     short result;		       /* button that was pushed */
-    short done;
-
-    KeyCode retKey;
-    KeyCode escKey;
 } WMAlertPanel;
 
 
+typedef struct WMGenericPanel {
+    WMWindow *win;
+    WMBox *vbox;
+    
+    WMLabel *iLbl;
+    WMLabel *tLbl;
+    
+    WMFrame *line;
+    
+    WMFrame *content;
+    
+    WMBox *buttonBox;
+    WMButton *defBtn;
+    WMButton *altBtn;
+    
+    short result;
+} WMGenericPanel;
+
+
+
+
 typedef struct WMInputPanel {
     WMWindow *win;		       /* window */
     WMButton *defBtn;		       /* default button */
@@ -407,15 +426,9 @@ typedef struct WMInputPanel {
     WMLabel *mLbl;		       /* message label */
     WMTextField *text;		       /* text field */
     short result;		       /* button that was pushed */
-    short done;
-
-    KeyCode retKey;
-    KeyCode escKey;
 } WMInputPanel;
 
 
-
-
 /* WMRuler: */
 typedef struct {
     WMArray  *tabs;             /* a growable array of tabstops */
@@ -428,10 +441,6 @@ typedef struct {
 /* All indentation and tab markers are _relative_ to the left margin marker */
 
 
-typedef void *WMHandlerID;
-
-typedef void WMInputProc(int fd, int mask, void *clientData);
-
 typedef void WMEventProc(XEvent *event, void *clientData);
 
 typedef void WMEventHook(XEvent *event);
@@ -444,8 +453,6 @@ typedef void WMAction(WMWidget *self, void *clientData);
 typedef void WMAction2(void *self, void *clientData);
 
 
-typedef void WMCallback(void *data);
-
 typedef void WMDropDataCallback(WMView *view, WMData *data);
 
 /* delegate method like stuff */
@@ -461,7 +468,7 @@ typedef void WMSplitViewResizeSubviewsProc(WMSplitView *sPtr,
 typedef void WMSplitViewConstrainProc(WMSplitView *sPtr, int dividerIndex,
 				      int *minSize, int *maxSize);
 
-typedef WMWidget *WMMatrixCreateCellProc(WMMatrix *mPtr);
+typedef WMWidget* WMMatrixCreateCellProc(WMMatrix *mPtr);
 
 
 
@@ -571,12 +578,14 @@ typedef struct W_DragDestinationProcs {
 /* ...................................................................... */
 
 
-WMRange wmkrange(int start, int count);
-
 WMPoint wmkpoint(int x, int y);
 
 WMSize wmksize(unsigned int width, unsigned int height);
 
+#ifdef ANSI_C_DOESNT_LIKE_IT_THIS_WAY
+#define wmksize(width, height) (WMSize){(width), (height)}
+#define wmkpoint(x, y)         (WMPoint){(x), (y)}
+#endif
 
 /* ....................................................................... */
 
@@ -587,20 +596,20 @@ void WMInitializeApplication(char *applicationName, int *argc, char **argv);
 void WMSetResourcePath(char *path);
 
 /* don't free the returned string */
-char *WMGetApplicationName();
+char* WMGetApplicationName();
 
 /* Try to locate resource file. ext may be NULL */
-char *WMPathForResourceOfType(char *resource, char *ext);
+char* WMPathForResourceOfType(char *resource, char *ext);
 
 
-WMScreen *WMOpenScreen();
+WMScreen* WMOpenScreen(const char *display);
 
-WMScreen *WMCreateScreenWithRContext(Display *display, int screen, 
+WMScreen* WMCreateScreenWithRContext(Display *display, int screen,
 				     RContext *context);
 
-WMScreen *WMCreateScreen(Display *display, int screen);
+WMScreen* WMCreateScreen(Display *display, int screen);
 
-WMScreen *WMCreateSimpleApplicationScreen(Display *display);
+WMScreen* WMCreateSimpleApplicationScreen(Display *display);
 
 void WMScreenMainLoop(WMScreen *scr);
 
@@ -608,23 +617,30 @@ void WMBreakModalLoop(WMScreen *scr);
 
 void WMRunModalLoop(WMScreen *scr, WMView *view);
 
-RContext *WMScreenRContext(WMScreen *scr);
+RContext* WMScreenRContext(WMScreen *scr);
 
-Display *WMScreenDisplay(WMScreen *scr);
+Display* WMScreenDisplay(WMScreen *scr);
 
 int WMScreenDepth(WMScreen *scr);
 
 
 
-void WMSetApplicationIconImage(WMScreen *app, WMPixmap *icon);
+void WMSetApplicationIconImage(WMScreen *app, RImage *image);
 
-WMPixmap *WMGetApplicationIconImage(WMScreen *app);
+RImage* WMGetApplicationIconImage(WMScreen *app);
+
+void WMSetApplicationIconPixmap(WMScreen *app, WMPixmap *icon);
+
+WMPixmap* WMGetApplicationIconPixmap(WMScreen *app);
+
+/* If color==NULL it will use the default color for panels: ae/aa/ae */
+WMPixmap* WMCreateApplicationIconBlendedPixmap(WMScreen *scr, RColor *color);
 
 void WMSetApplicationIconWindow(WMScreen *scr, Window window);
 
 void WMSetFocusToWidget(WMWidget *widget);
 
-WMEventHook *WMHookEventHandler(WMEventHook *handler);
+WMEventHook* WMHookEventHandler(WMEventHook *handler);
 
 int WMHandleEvent(XEvent *event);
 
@@ -638,28 +654,14 @@ void WMDeleteEventHandler(WMView *view, unsigned long mask,
 
 int WMIsDoubleClick(XEvent *event);
 
-int WMIsTripleClick(XEvent *event);
+/*int WMIsTripleClick(XEvent *event);*/
 
 void WMNextEvent(Display *dpy, XEvent *event);
 
 void WMMaskEvent(Display *dpy, long mask, XEvent *event);
 
-WMHandlerID WMAddTimerHandler(int milliseconds, WMCallback *callback, 
-			      void *cdata);
-
-void WMDeleteTimerWithClientData(void *cdata);
-
-void WMDeleteTimerHandler(WMHandlerID handlerID);
-
-WMHandlerID WMAddIdleHandler(WMCallback *callback, void *cdata);
-
-void WMDeleteIdleHandler(WMHandlerID handlerID);
-
-WMHandlerID WMAddInputHandler(int fd, int condition, WMInputProc *proc, 
-			      void *clientData);
-
-void WMDeleteInputHandler(WMHandlerID handlerID);
 
+/* ....................................................................... */
 
 
 Bool WMCreateSelectionHandler(WMView *view, Atom selection, Time timestamp,
@@ -672,6 +674,8 @@ Bool WMRequestSelection(WMView *view, Atom selection, Atom target,
 			void *cdata);
 
 
+extern char *WMSelectionOwnerDidChangeNotification;
+
 /* ....................................................................... */
 
 void WMSetViewDragSourceProcs(WMView *view, WMDragSourceProcs *procs);
@@ -691,22 +695,22 @@ WMPoint WMGetDraggingInfoImageLocation(WMDraggingInfo *info);
 
 /* ....................................................................... */
 
-WMFont *WMCreateFontSet(WMScreen *scrPtr, char *fontName);
+WMFont* WMCreateFontSet(WMScreen *scrPtr, char *fontName);
 
-WMFont *WMCreateNormalFont(WMScreen *scrPtr, char *fontName);
+WMFont* WMCreateNormalFont(WMScreen *scrPtr, char *fontName);
 
-WMFont *WMCreateFont(WMScreen *scrPtr, char *fontName);
+WMFont* WMCreateFont(WMScreen *scrPtr, char *fontName);
 
-WMFont *WMRetainFont(WMFont *font);
+WMFont* WMRetainFont(WMFont *font);
 
 void WMReleaseFont(WMFont *font);
 
 unsigned int WMFontHeight(WMFont *font);
 
 /*
-WMFont *WMUserFontOfSize(WMScreen *scrPtr, int size);
+WMFont* WMUserFontOfSize(WMScreen *scrPtr, int size);
 
-WMFont *WMUserFixedPitchFontOfSize(WMScreen *scrPtr, int size);
+WMFont* WMUserFixedPitchFontOfSize(WMScreen *scrPtr, int size);
 */
 
 
@@ -714,47 +718,54 @@ void WMSetWidgetDefaultFont(WMScreen *scr, WMFont *font);
 
 void WMSetWidgetDefaultBoldFont(WMScreen *scr, WMFont *font);
 
-WMFont *WMSystemFontOfSize(WMScreen *scrPtr, int size);
+WMFont* WMDefaultSystemFont(WMScreen *scrPtr);
 
-WMFont *WMBoldSystemFontOfSize(WMScreen *scrPtr, int size);
+WMFont* WMDefaultBoldSystemFont(WMScreen *scrPtr);
+
+WMFont* WMSystemFontOfSize(WMScreen *scrPtr, int size);
+
+WMFont* WMBoldSystemFontOfSize(WMScreen *scrPtr, int size);
 
 XFontSet WMGetFontFontSet(WMFont *font);
 
-WMFont * WMNormalizeFont(WMScreen *scr, WMFont *font);
+WMFont* WMNormalizeFont(WMScreen *scr, WMFont *font);
 
-WMFont * WMStrengthenFont(WMScreen *scr, WMFont *font);
+WMFont* WMStrengthenFont(WMScreen *scr, WMFont *font);
 
-WMFont * WMUnstrengthenFont(WMScreen *scr, WMFont *font);
+WMFont* WMUnstrengthenFont(WMScreen *scr, WMFont *font);
 
-WMFont * WMEmphasizeFont(WMScreen *scr, WMFont *font);
+WMFont* WMEmphasizeFont(WMScreen *scr, WMFont *font);
 
-WMFont * WMUnemphasizeFont(WMScreen *scr, WMFont *font);
+WMFont* WMUnemphasizeFont(WMScreen *scr, WMFont *font);
 
-WMFont * WMGetFontOfSize(WMScreen *scr, WMFont *font, int size);
+WMFont* WMGetFontOfSize(WMScreen *scr, WMFont *font, int size);
 
 /* ....................................................................... */
 
-WMPixmap *WMRetainPixmap(WMPixmap *pixmap);
+WMPixmap* WMRetainPixmap(WMPixmap *pixmap);
 
 void WMReleasePixmap(WMPixmap *pixmap);
 
-WMPixmap *WMCreatePixmap(WMScreen *scrPtr, int width, int height, int depth,
+WMPixmap* WMCreatePixmap(WMScreen *scrPtr, int width, int height, int depth,
 			 Bool masked);
 
-WMPixmap *WMCreatePixmapFromXPixmaps(WMScreen *scrPtr, Pixmap pixmap, 
+WMPixmap* WMCreatePixmapFromXPixmaps(WMScreen *scrPtr, Pixmap pixmap,
 				     Pixmap mask, int width, int height,
 				     int depth);
 
-WMPixmap *WMCreatePixmapFromRImage(WMScreen *scrPtr, RImage *image, 
+WMPixmap* WMCreatePixmapFromRImage(WMScreen *scrPtr, RImage *image,
 				   int threshold);
 
-WMPixmap *WMCreatePixmapFromXPMData(WMScreen *scrPtr, char **data);
+WMPixmap* WMCreatePixmapFromXPMData(WMScreen *scrPtr, char **data);
 
 WMSize WMGetPixmapSize(WMPixmap *pixmap);
 
-WMPixmap *WMCreatePixmapFromFile(WMScreen *scrPtr, char *fileName);
+WMPixmap* WMCreatePixmapFromFile(WMScreen *scrPtr, char *fileName);
 
-WMPixmap *WMCreateBlendedPixmapFromFile(WMScreen *scrPtr, char *fileName,
+WMPixmap* WMCreateBlendedPixmapFromRImage(WMScreen *scrPtr, RImage *image,
+                                          RColor *color);
+
+WMPixmap* WMCreateBlendedPixmapFromFile(WMScreen *scrPtr, char *fileName,
 					RColor *color);
 
 void WMDrawPixmap(WMPixmap *pixmap, Drawable d, int x, int y);
@@ -763,18 +774,18 @@ Pixmap WMGetPixmapXID(WMPixmap *pixmap);
 
 Pixmap WMGetPixmapMaskXID(WMPixmap *pixmap);
 
-WMPixmap *WMGetSystemPixmap(WMScreen *scr, int image);
+WMPixmap* WMGetSystemPixmap(WMScreen *scr, int image);
 
 /* ....................................................................... */
 
 
-WMColor *WMDarkGrayColor(WMScreen *scr);
+WMColor* WMDarkGrayColor(WMScreen *scr);
 
-WMColor *WMGrayColor(WMScreen *scr);
+WMColor* WMGrayColor(WMScreen *scr);
 
-WMColor *WMBlackColor(WMScreen *scr);
+WMColor* WMBlackColor(WMScreen *scr);
 
-WMColor *WMWhiteColor(WMScreen *scr);
+WMColor* WMWhiteColor(WMScreen *scr);
 
 void WMSetColorInGC(WMColor *color, GC gc);
 
@@ -787,13 +798,13 @@ void WMPaintColorSwatch(WMColor *color, Drawable d, int x, int y,
 
 void WMReleaseColor(WMColor *color);
 
-WMColor *WMRetainColor(WMColor *color);
+WMColor* WMRetainColor(WMColor *color);
 
-WMColor *WMCreateRGBColor(WMScreen *scr, unsigned short red, 
+WMColor* WMCreateRGBColor(WMScreen *scr, unsigned short red,
 			  unsigned short green, unsigned short blue,
 			  Bool exact);
 
-WMColor *WMCreateNamedColor(WMScreen *scr, char *name, Bool exact);
+WMColor* WMCreateNamedColor(WMScreen *scr, char *name, Bool exact);
 
 unsigned short WMRedComponentOfColor(WMColor *color);
 
@@ -801,7 +812,7 @@ unsigned short WMGreenComponentOfColor(WMColor *color);
 
 unsigned short WMBlueComponentOfColor(WMColor *color);
 
-char *WMGetColorRGBDescription(WMColor *color);
+char* WMGetColorRGBDescription(WMColor *color);
 
 /* ....................................................................... */
 
@@ -818,7 +829,7 @@ int WMWidthOfString(WMFont *font, char *text, int length);
 
 /* ....................................................................... */
 
-WMScreen *WMWidgetScreen(WMWidget *w);
+WMScreen* WMWidgetScreen(WMWidget *w);
 
 unsigned int WMScreenWidth(WMScreen *scr);
 
@@ -846,11 +857,13 @@ void WMUnmapSubwidgets(WMWidget *w);
 
 void WMRealizeWidget(WMWidget *w);
 
+void WMReparentWidget(WMWidget *w, WMWidget *newParent, int x, int y);
+
 void WMDestroyWidget(WMWidget *widget);
 
 void WMHangData(WMWidget *widget, void *data);
 
-void *WMGetHangedData(WMWidget *widget);
+void* WMGetHangedData(WMWidget *widget);
 
 unsigned int WMWidgetWidth(WMWidget *w);
 
@@ -864,13 +877,16 @@ void WMRedisplayWidget(WMWidget *w);
 
 void WMSetViewNotifySizeChanges(WMView *view, Bool flag);
 
+void WMSetViewExpandsToParent(WMView *view, int topOffs, int leftOffs, 
+			      int rightOffs, int bottomOffs);
+
 WMSize WMGetViewSize(WMView *view);
 
 WMPoint WMGetViewPosition(WMView *view);
 
 WMPoint WMGetViewScreenPosition(WMView *view);
 
-WMWidget *WMWidgetOfView(WMView *view);
+WMWidget* WMWidgetOfView(WMView *view);
 
 void WMSetViewNextResponder(WMView *view, WMView *responder);
 
@@ -879,9 +895,9 @@ void WMRelayToNextResponder(WMView *view, XEvent *event);
 /* notifications */
 extern char *WMViewSizeDidChangeNotification;
 
-extern char *WMViewRealizedNotification;
+extern char *WMViewFocusDidChangeNotification;
 
-extern char *WMFontPanelDidChangeNotification;
+extern char *WMViewRealizedNotification;
 
 
 /* ....................................................................... */
@@ -901,14 +917,14 @@ void WMSetBalloonEnabled(WMScreen *scr, Bool flag);
 
 /* ....................................................................... */
 
-WMWindow *WMCreateWindow(WMScreen *screen, char *name);
+WMWindow* WMCreateWindow(WMScreen *screen, char *name);
 
-WMWindow *WMCreateWindowWithStyle(WMScreen *screen, char *name, int style);
+WMWindow* WMCreateWindowWithStyle(WMScreen *screen, char *name, int style);
 
-WMWindow *WMCreatePanelWithStyleForWindow(WMWindow *owner, char *name, 
+WMWindow* WMCreatePanelWithStyleForWindow(WMWindow *owner, char *name,
 					  int style);
 
-WMWindow *WMCreatePanelForWindow(WMWindow *owner, char *name);
+WMWindow* WMCreatePanelForWindow(WMWindow *owner, char *name);
 
 void WMChangePanelOwner(WMWindow *win, WMWindow *newOwner);
 
@@ -916,7 +932,7 @@ void WMSetWindowTitle(WMWindow *wPtr, char *title);
 
 void WMSetWindowMiniwindowTitle(WMWindow *win, char *title);
 
-void WMSetWindowMiniwindowImage(WMWindow *win, WMPixmap *pixmap);
+void WMSetWindowMiniwindowPixmap(WMWindow *win, WMPixmap *pixmap);
 
 void WMSetWindowCloseAction(WMWindow *win, WMAction *action, void *clientData);
 
@@ -957,9 +973,9 @@ void WMSetButtonAction(WMButton *bPtr, WMAction *action, void *clientData);
 #define WMCreateSwitchButton(parent) \
 	WMCreateButton((parent), WBTSwitch)
 
-WMButton *WMCreateButton(WMWidget *parent, WMButtonType type);
+WMButton* WMCreateButton(WMWidget *parent, WMButtonType type);
 
-WMButton *WMCreateCustomButton(WMWidget *parent, int behaviourMask);
+WMButton* WMCreateCustomButton(WMWidget *parent, int behaviourMask);
 
 void WMSetButtonImageDefault(WMButton *bPtr);
 
@@ -991,6 +1007,8 @@ void WMSetButtonBordered(WMButton *bPtr, int isBordered);
 
 void WMSetButtonEnabled(WMButton *bPtr, Bool flag);
 
+int WMGetButtonEnabled(WMButton *bPtr);
+
 void WMSetButtonImageDimsWhenDisabled(WMButton *bPtr, Bool flag);
 
 void WMSetButtonTag(WMButton *bPtr, int tag);
@@ -1005,15 +1023,15 @@ void WMSetButtonPeriodicDelay(WMButton *bPtr, float delay, float interval);
 
 /* ....................................................................... */
 
-WMLabel *WMCreateLabel(WMWidget *parent);
+WMLabel* WMCreateLabel(WMWidget *parent);
 
 void WMSetLabelWraps(WMLabel *lPtr, Bool flag);
 
 void WMSetLabelImage(WMLabel *lPtr, WMPixmap *image);
 
-WMPixmap *WMGetLabelImage(WMLabel *lPtr);
+WMPixmap* WMGetLabelImage(WMLabel *lPtr);
 
-char *WMGetLabelText(WMLabel *lPtr);
+char* WMGetLabelText(WMLabel *lPtr);
 
 void WMSetLabelImagePosition(WMLabel *lPtr, WMImagePosition position);
 
@@ -1023,13 +1041,15 @@ void WMSetLabelRelief(WMLabel *lPtr, WMReliefType relief);
 
 void WMSetLabelText(WMLabel *lPtr, char *text);
 
+WMFont* WMGetLabelFont(WMLabel *lPtr);
+
 void WMSetLabelFont(WMLabel *lPtr, WMFont *font);
 
 void WMSetLabelTextColor(WMLabel *lPtr, WMColor *color);
 
 /* ....................................................................... */
 
-WMFrame *WMCreateFrame(WMWidget *parent);
+WMFrame* WMCreateFrame(WMWidget *parent);
 
 void WMSetFrameTitlePosition(WMFrame *fPtr, WMTitlePosition position);
 
@@ -1039,14 +1059,14 @@ void WMSetFrameTitle(WMFrame *fPtr, char *title);
 
 /* ....................................................................... */
 
-WMTextField *WMCreateTextField(WMWidget *parent);
+WMTextField* WMCreateTextField(WMWidget *parent);
 
 void WMInsertTextFieldText(WMTextField *tPtr, char *text, int position);
 
 void WMDeleteTextFieldRange(WMTextField *tPtr, WMRange range);
 
 /* you can free the returned string */
-char *WMGetTextFieldText(WMTextField *tPtr);
+char* WMGetTextFieldText(WMTextField *tPtr);
 
 void WMSetTextFieldText(WMTextField *tPtr, char *text);
 
@@ -1054,7 +1074,7 @@ void WMSetTextFieldAlignment(WMTextField *tPtr, WMAlignment alignment);
 
 void WMSetTextFieldFont(WMTextField *tPtr, WMFont *font);
 
-WMFont *WMGetTextFieldFont(WMTextField *tPtr);
+WMFont* WMGetTextFieldFont(WMTextField *tPtr);
 
 void WMSetTextFieldBordered(WMTextField *tPtr, Bool bordered);
 
@@ -1076,6 +1096,7 @@ void WMSetTextFieldPrevTextField(WMTextField *tPtr, WMTextField *prev);
 
 void WMSetTextFieldDelegate(WMTextField *tPtr, WMTextFieldDelegate *delegate);
 
+WMTextFieldDelegate* WMGetTextFieldDelegate(WMTextField *tPtr);
 
 extern char *WMTextDidChangeNotification;
 extern char *WMTextDidBeginEditingNotification;
@@ -1083,7 +1104,7 @@ extern char *WMTextDidEndEditingNotification;
 
 /* ....................................................................... */
 
-WMScroller *WMCreateScroller(WMWidget *parent);
+WMScroller* WMCreateScroller(WMWidget *parent);
 
 void WMSetScrollerParameters(WMScroller *sPtr, float floatValue, 
 			     float knobProportion);
@@ -1103,7 +1124,7 @@ extern char *WMScrollerDidScrollNotification;
 
 /* ....................................................................... */
 
-WMList *WMCreateList(WMWidget *parent);
+WMList* WMCreateList(WMWidget *parent);
 
 void WMSetListAllowMultipleSelection(WMList *lPtr, Bool flag);
 
@@ -1111,7 +1132,7 @@ void WMSetListAllowEmptySelection(WMList *lPtr, Bool flag);
 
 #define WMAddListItem(lPtr, text) WMInsertListItem((lPtr), -1, (text))
 
-WMListItem *WMInsertListItem(WMList *lPtr, int row, char *text);
+WMListItem* WMInsertListItem(WMList *lPtr, int row, char *text);
 
 void WMSortListItems(WMList *lPtr);
 
@@ -1119,9 +1140,9 @@ void WMSortListItemsWithComparer(WMList *lPtr, WMCompareDataProc *func);
 
 int WMFindRowOfListItemWithTitle(WMList *lPtr, char *title);
 
-WMListItem *WMGetListItem(WMList *lPtr, int row);
+WMListItem* WMGetListItem(WMList *lPtr, int row);
 
-WMArray *WMGetListItems(WMList *lPtr);
+WMArray* WMGetListItems(WMList *lPtr);
 
 void WMRemoveListItem(WMList *lPtr, int row);
 
@@ -1183,7 +1204,7 @@ extern char *WMListSelectionDidChangeNotification;
 
 /* ....................................................................... */
 
-WMBrowser *WMCreateBrowser(WMWidget *parent);
+WMBrowser* WMCreateBrowser(WMWidget *parent);
 
 void WMSetBrowserAllowMultipleSelection(WMBrowser *bPtr, Bool flag);
 
@@ -1203,7 +1224,7 @@ void WMSetBrowserMaxVisibleColumns(WMBrowser *bPtr, int columns);
 
 void WMSetBrowserColumnTitle(WMBrowser *bPtr, int column, char *title);
 
-WMListItem *WMInsertBrowserItem(WMBrowser *bPtr, int column, int row, char *text, Bool isBranch);
+WMListItem* WMInsertBrowserItem(WMBrowser *bPtr, int column, int row, char *text, Bool isBranch);
 
 void WMSortBrowserColumn(WMBrowser *bPtr, int column);
 
@@ -1214,10 +1235,10 @@ void WMSortBrowserColumnWithComparer(WMBrowser *bPtr, int column,
 char* WMSetBrowserPath(WMBrowser *bPtr, char *path);
 
 /* free the returned string */
-char *WMGetBrowserPath(WMBrowser *bPtr);
+char* WMGetBrowserPath(WMBrowser *bPtr);
 
 /* free the returned string */
-char *WMGetBrowserPathToColumn(WMBrowser *bPtr, int column);
+char* WMGetBrowserPathToColumn(WMBrowser *bPtr, int column);
 
 /* free the returned array */
 WMArray* WMGetBrowserPaths(WMBrowser *bPtr);
@@ -1227,7 +1248,7 @@ void WMSetBrowserAction(WMBrowser *bPtr, WMAction *action, void *clientData);
 void WMSetBrowserDoubleAction(WMBrowser *bPtr, WMAction *action, 
 			      void *clientData);
 
-WMListItem *WMGetBrowserSelectedItemInColumn(WMBrowser *bPtr, int column);
+WMListItem* WMGetBrowserSelectedItemInColumn(WMBrowser *bPtr, int column);
 
 int WMGetBrowserFirstVisibleColumn(WMBrowser *bPtr);
 
@@ -1239,7 +1260,7 @@ int WMGetBrowserNumberOfColumns(WMBrowser *bPtr);
 
 int WMGetBrowserMaxVisibleColumns(WMBrowser *bPtr);
 
-WMList *WMGetBrowserListInColumn(WMBrowser *bPtr, int column);
+WMList* WMGetBrowserListInColumn(WMBrowser *bPtr, int column);
 
 void WMSetBrowserDelegate(WMBrowser *bPtr, WMBrowserDelegate *delegate);
 
@@ -1254,7 +1275,7 @@ void WMSetBrowserHasScroller(WMBrowser *bPtr, int hasScroller);
 
 Bool WMMenuItemIsSeparator(WMMenuItem *item);
 
-WMMenuItem *WMCreateMenuItem(void);
+WMMenuItem* WMCreateMenuItem(void);
 
 void WMDestroyMenuItem(WMMenuItem *item);
 
@@ -1262,7 +1283,7 @@ Bool WMGetMenuItemEnabled(WMMenuItem *item);
 
 void WMSetMenuItemEnabled(WMMenuItem *item, Bool flag);
 
-char *WMGetMenuItemShortcut(WMMenuItem *item);
+char* WMGetMenuItemShortcut(WMMenuItem *item);
 
 unsigned WMGetMenuItemShortcutModifierMask(WMMenuItem *item);
 
@@ -1270,19 +1291,19 @@ void WMSetMenuItemShortcut(WMMenuItem *item, char *shortcut);
 
 void WMSetMenuItemShortcutModifierMask(WMMenuItem *item, unsigned mask);
 
-void *WMGetMenuItemRepresentedObject(WMMenuItem *item);
+void* WMGetMenuItemRepresentedObject(WMMenuItem *item);
 
 void WMSetMenuItemRepresentedObject(WMMenuItem *item, void *object);
 
 void WMSetMenuItemAction(WMMenuItem *item, WMAction *action, void *data);
 
-WMAction *WMGetMenuItemAction(WMMenuItem *item);
+WMAction* WMGetMenuItemAction(WMMenuItem *item);
 
-void *WMGetMenuItemData(WMMenuItem *item);
+void* WMGetMenuItemData(WMMenuItem *item);
 
 void WMSetMenuItemTitle(WMMenuItem *item, char *title);
 
-char *WMGetMenuItemTitle(WMMenuItem *item);
+char* WMGetMenuItemTitle(WMMenuItem *item);
 
 void WMSetMenuItemState(WMMenuItem *item, int state);
 
@@ -1290,40 +1311,40 @@ int WMGetMenuItemState(WMMenuItem *item);
 
 void WMSetMenuItemPixmap(WMMenuItem *item, WMPixmap *pixmap);
 
-WMPixmap *WMGetMenuItemPixmap(WMMenuItem *item);
+WMPixmap* WMGetMenuItemPixmap(WMMenuItem *item);
 
 void WMSetMenuItemOnStatePixmap(WMMenuItem *item, WMPixmap *pixmap);
 
-WMPixmap *WMGetMenuItemOnStatePixmap(WMMenuItem *item);
+WMPixmap* WMGetMenuItemOnStatePixmap(WMMenuItem *item);
 
 void WMSetMenuItemOffStatePixmap(WMMenuItem *item, WMPixmap *pixmap);
 
-WMPixmap *WMGetMenuItemOffStatePixmap(WMMenuItem *item);
+WMPixmap* WMGetMenuItemOffStatePixmap(WMMenuItem *item);
 
 void WMSetMenuItemMixedStatePixmap(WMMenuItem *item, WMPixmap *pixmap);
 
-WMPixmap *WMGetMenuItemMixedStatePixmap(WMMenuItem *item);
+WMPixmap* WMGetMenuItemMixedStatePixmap(WMMenuItem *item);
 
 /*void WMSetMenuItemSubmenu(WMMenuItem *item, WMMenu *submenu);
  
 
-WMMenu *WMGetMenuItemSubmenu(WMMenuItem *item);
+WMMenu* WMGetMenuItemSubmenu(WMMenuItem *item);
 
 Bool WMGetMenuItemHasSubmenu(WMMenuItem *item);
  */
 
 /* ....................................................................... */
 
-WMPopUpButton *WMCreatePopUpButton(WMWidget *parent);
+WMPopUpButton* WMCreatePopUpButton(WMWidget *parent);
 
 void WMSetPopUpButtonAction(WMPopUpButton *sPtr, WMAction *action, 
 			    void *clientData);
 
 void WMSetPopUpButtonPullsDown(WMPopUpButton *bPtr, Bool flag);
 
-WMMenuItem *WMAddPopUpButtonItem(WMPopUpButton *bPtr, char *title);
+WMMenuItem* WMAddPopUpButtonItem(WMPopUpButton *bPtr, char *title);
 
-WMMenuItem *WMInsertPopUpButtonItem(WMPopUpButton *bPtr, int index, 
+WMMenuItem* WMInsertPopUpButtonItem(WMPopUpButton *bPtr, int index,
 				    char *title);
 
 void WMRemovePopUpButtonItem(WMPopUpButton *bPtr, int index);
@@ -1339,9 +1360,9 @@ int WMGetPopUpButtonSelectedItem(WMPopUpButton *bPtr);
 void WMSetPopUpButtonText(WMPopUpButton *bPtr, char *text);
 
 /* don't free the returned data */
-char *WMGetPopUpButtonItem(WMPopUpButton *bPtr, int index);
+char* WMGetPopUpButtonItem(WMPopUpButton *bPtr, int index);
 
-WMMenuItem *WMGetPopUpButtonMenuItem(WMPopUpButton *bPtr, int index);
+WMMenuItem* WMGetPopUpButtonMenuItem(WMPopUpButton *bPtr, int index);
 
 
 int WMGetPopUpButtonNumberOfItems(WMPopUpButton *bPtr);
@@ -1352,7 +1373,7 @@ Bool WMGetPopUpButtonEnabled(WMPopUpButton *bPtr);
 
 /* ....................................................................... */
 
-WMProgressIndicator *WMCreateProgressIndicator(WMWidget *parent);
+WMProgressIndicator* WMCreateProgressIndicator(WMWidget *parent);
 
 void WMSetProgressIndicatorMinValue(WMProgressIndicator *progressindicator, int value);
 
@@ -1369,7 +1390,7 @@ int WMGetProgressIndicatorValue(WMProgressIndicator *progressindicator);
 
 /* ....................................................................... */
 
-WMColorPanel *WMGetColorPanel(WMScreen *scrPtr);
+WMColorPanel* WMGetColorPanel(WMScreen *scrPtr);
 
 void WMFreeColorPanel(WMColorPanel *panel);
 
@@ -1379,7 +1400,7 @@ void WMCloseColorPanel(WMColorPanel *panel);
 
 void WMSetColorPanelColor(WMColorPanel *panel, WMColor *color);
 
-WMColor *WMGetColorPanelColor(WMColorPanel *panel);
+WMColor* WMGetColorPanelColor(WMColorPanel *panel);
 
 void WMSetColorPanelPickerMode(WMColorPanel *panel, WMColorPanelMode mode);
 
@@ -1389,11 +1410,11 @@ extern char *WMColorPanelColorChangedNotification;
 
 /* ....................................................................... */
 
-WMColorWell *WMCreateColorWell(WMWidget *parent);
+WMColorWell* WMCreateColorWell(WMWidget *parent);
 
 void WMSetColorWellColor(WMColorWell *cPtr, WMColor *color);
 
-WMColor *WMGetColorWellColor(WMColorWell *cPtr);
+WMColor* WMGetColorWellColor(WMColorWell *cPtr);
 
 void WSetColorWellBordered(WMColorWell *cPtr, Bool flag);
 
@@ -1403,7 +1424,7 @@ extern char *WMColorWellDidChangeNotification;
 
 /* ...................................................................... */
 
-WMScrollView *WMCreateScrollView(WMWidget *parent);
+WMScrollView* WMCreateScrollView(WMWidget *parent);
 
 void WMResizeScrollViewContent(WMScrollView *sPtr, unsigned int width,
 			       unsigned int height);
@@ -1416,13 +1437,11 @@ void WMSetScrollViewContentView(WMScrollView *sPtr, WMView *view);
 
 void WMSetScrollViewRelief(WMScrollView *sPtr, WMReliefType type);
 
-void WMSetScrollViewContentView(WMScrollView *sPtr, WMView *view);
-
 WMRect WMGetScrollViewVisibleRect(WMScrollView *sPtr);
 
-WMScroller *WMGetScrollViewHorizontalScroller(WMScrollView *sPtr);
+WMScroller* WMGetScrollViewHorizontalScroller(WMScrollView *sPtr);
 
-WMScroller *WMGetScrollViewVerticalScroller(WMScrollView *sPtr);
+WMScroller* WMGetScrollViewVerticalScroller(WMScrollView *sPtr);
 
 void WMSetScrollViewLineScroll(WMScrollView *sPtr, int amount);
 
@@ -1430,7 +1449,7 @@ void WMSetScrollViewPageScroll(WMScrollView *sPtr, int amount);
 
 /* ....................................................................... */
 
-WMSlider *WMCreateSlider(WMWidget *parent);
+WMSlider* WMCreateSlider(WMWidget *parent);
 
 int WMGetSliderMinValue(WMSlider *slider);
 
@@ -1455,13 +1474,15 @@ void WMSetSliderImage(WMSlider *sPtr, WMPixmap *pixmap);
 /* ....................................................................... */
 
 
-WMSplitView *WMCreateSplitView(WMWidget *parent);
+WMSplitView* WMCreateSplitView(WMWidget *parent);
+
 Bool WMGetSplitViewVertical(WMSplitView *sPtr);
+
 void WMSetSplitViewVertical(WMSplitView *sPtr, Bool flag);
 
 int WMGetSplitViewSubviewsCount(WMSplitView *sPtr); /* ??? remove ??? */
 
-WMView *WMGetSplitViewSubviewAt(WMSplitView *sPtr, int index);
+WMView* WMGetSplitViewSubviewAt(WMSplitView *sPtr, int index);
 
 /* remove the first subview == view */
 void WMRemoveSplitViewSubview(WMSplitView *sPtr, WMView *view);
@@ -1485,14 +1506,13 @@ int WMGetSplitViewDividerThickness(WMSplitView *sPtr);
 
 /* ...................................................................... */
 
-WMRuler *WMCreateRuler (WMWidget *parent);
+WMRuler* WMCreateRuler (WMWidget *parent);
 
-WMRulerMargins *WMGetRulerMargins(WMRuler *rPtr);
+WMRulerMargins* WMGetRulerMargins(WMRuler *rPtr);
 
 void WMSetRulerMargins(WMRuler *rPtr, WMRulerMargins margins);
 
-Bool WMIsMarginEqualToMargin(WMRulerMargins *aMargin,
-    WMRulerMargins *anotherMargin);
+Bool WMIsMarginEqualToMargin(WMRulerMargins *aMargin, WMRulerMargins *anotherMargin);
 
 int WMGetGrabbedRulerMargin(WMRuler *rPtr);
 
@@ -1512,8 +1532,8 @@ void WMSetRulerReleaseAction(WMRuler *rPtr, WMAction *action, void *clientData);
 #define WMCreateText(parent) WMCreateTextForDocumentType \
     ((parent), (NULL), (NULL))
 
-WMText *WMCreateTextForDocumentType(WMWidget *parent, 
-	WMAction *parser, WMAction *writer);
+WMText* WMCreateTextForDocumentType(WMWidget *parent, WMAction *parser,
+                                    WMAction *writer);
 
 void WMSetTextDelegate(WMText *tPtr, WMTextDelegate *delegate);
 
@@ -1553,11 +1573,11 @@ int WMGetTextIgnoresNewline(WMText *tPtr);
 
 void WMSetTextDefaultFont(WMText *tPtr, WMFont *font);
 
-WMFont * WMGetTextDefaultFont(WMText *tPtr);
+WMFont* WMGetTextDefaultFont(WMText *tPtr);
 
 void WMSetTextDefaultColor(WMText *tPtr, WMColor *color);
 
-WMColor * WMGetTextDefaultColor(WMText *tPtr);
+WMColor* WMGetTextDefaultColor(WMText *tPtr);
 
 void WMSetTextRelief(WMText *tPtr, WMReliefType relief);
 
@@ -1571,25 +1591,28 @@ void WMPrependTextStream(WMText *tPtr, char *text);
 
 void WMAppendTextStream(WMText *tPtr, char *text);
 
-/* free the text */
-char * WMGetTextStream(WMText *tPtr);
+#define WMClearText(tPtr) WMAppendTextStream \
+    ((tPtr), (NULL))
 
 /* free the text */
-char * WMGetTextSelectedStream(WMText *tPtr);
+char* WMGetTextStream(WMText *tPtr);
+
+/* free the text */
+char* WMGetTextSelectedStream(WMText *tPtr);
 
 /* destroy the array */
-WMArray * WMGetTextObjects(WMText *tPtr);
+WMArray* WMGetTextObjects(WMText *tPtr);
 
 /* destroy the array */
 WMArray* WMGetTextSelectedObjects(WMText *tPtr);
 
 void WMSetTextSelectionColor(WMText *tPtr, WMColor *color);
 
-WMColor *WMGetTextSelectionColor(WMText *tPtr);
+WMColor* WMGetTextSelectionColor(WMText *tPtr);
 
 void WMSetTextSelectionFont(WMText *tPtr, WMFont *font);
 
-WMFont *WMGetTextSelectionFont(WMText *tPtr);
+WMFont* WMGetTextSelectionFont(WMText *tPtr);
 
 void WMSetTextSelectionUnderlined(WMText *tPtr, int underlined);
 
@@ -1598,51 +1621,54 @@ int WMGetTextSelectionUnderlined(WMText *tPtr);
 void WMSetTextAlignment(WMText *tPtr, WMAlignment alignment);
 
 Bool WMFindInTextStream(WMText *tPtr, char *needle, Bool direction,
-    Bool caseSensitive);
+                        Bool caseSensitive);
 
 Bool WMReplaceTextSelection(WMText *tPtr, char *replacement);
 
 
 /* parser related stuff... use only if implementing a new parser */
 
-void *WMCreateTextBlockWithObject(WMText *tPtr, WMWidget *w, char *description,
-    WMColor *color, unsigned short first, unsigned short extraInfo);
-    
-void *WMCreateTextBlockWithPixmap(WMText *tPtr, WMPixmap *p, char *description, 
-	WMColor *color, unsigned short first, unsigned short extraInfo);
+void* WMCreateTextBlockWithObject(WMText *tPtr, WMWidget *w, char *description,
+                                  WMColor *color, unsigned short first,
+                                  unsigned short extraInfo);
+
+void* WMCreateTextBlockWithPixmap(WMText *tPtr, WMPixmap *p, char *description,
+                                  WMColor *color, unsigned short first,
+                                  unsigned short extraInfo);
+
+void* WMCreateTextBlockWithText(WMText *tPtr, char *text, WMFont *font,
+                                WMColor *color, unsigned short first,
+                                unsigned short length);
 
-void *WMCreateTextBlockWithText(WMText *tPtr, char *text, WMFont *font,
-    WMColor *color, unsigned short first, unsigned short length);
-    
 void WMSetTextBlockProperties(WMText *tPtr, void *vtb, unsigned int first,
-    unsigned int kanji, unsigned int underlined, int script,
-	WMRulerMargins *margins);
-    
+                              unsigned int kanji, unsigned int underlined,
+                              int script, WMRulerMargins *margins);
+
 /* do NOT free the margins */
 void WMGetTextBlockProperties(WMText *tPtr, void *vtb, unsigned int *first,
-    unsigned int *kanji, unsigned int *underlined, int *script,
-	WMRulerMargins *margins);
+                              unsigned int *kanji, unsigned int *underlined,
+                              int *script, WMRulerMargins *margins);
 
 int WMGetTextInsertType(WMText *tPtr);
 
-int WMGetTextBlocks(WMText *tPtr);
+/*int WMGetTextBlocks(WMText *tPtr);
 
 void WMSetCurrentTextBlock(WMText *tPtr, int current);
 
-int WMGetCurrentTextBlock(WMText *tPtr); 
+int WMGetCurrentTextBlock(WMText *tPtr);*/
 
 void WMPrependTextBlock(WMText *tPtr, void *vtb);
 
 void WMAppendTextBlock(WMText *tPtr, void *vtb);
 
-void *WMRemoveTextBlock(WMText *tPtr);
+void* WMRemoveTextBlock(WMText *tPtr);
 
 void WMDestroyTextBlock(WMText *tPtr, void *vtb);
 
 /* ....................................................................... */
 
 
-WMTabView *WMCreateTabView(WMWidget *parent);
+WMTabView* WMCreateTabView(WMWidget *parent);
 
 void WMSetTabViewType(WMTabView *tPtr, WMTabViewType type);
 
@@ -1656,10 +1682,10 @@ void WMInsertItemInTabView(WMTabView *tPtr, int index, WMTabViewItem *item);
 
 void WMRemoveTabViewItem(WMTabView *tPtr, WMTabViewItem *item);
 
-WMTabViewItem *WMAddTabViewItemWithView(WMTabView *tPtr, WMView *view, 
+WMTabViewItem* WMAddTabViewItemWithView(WMTabView *tPtr, WMView *view,
 					int identifier, char *label);
 
-WMTabViewItem *WMTabViewItemAtPoint(WMTabView *tPtr, int x, int y);
+WMTabViewItem* WMTabViewItemAtPoint(WMTabView *tPtr, int x, int y);
 
 void WMSelectFirstTabViewItem(WMTabView *tPtr);
 
@@ -1669,7 +1695,7 @@ void WMSelectNextTabViewItem(WMTabView *tPtr);
 
 void WMSelectPreviousTabViewItem(WMTabView *tPtr);
 
-WMTabViewItem *WMGetSelectedTabViewItem(WMTabView *tPtr);
+WMTabViewItem* WMGetSelectedTabViewItem(WMTabView *tPtr);
 
 void WMSelectTabViewItem(WMTabView *tPtr, WMTabViewItem *item);
 
@@ -1678,24 +1704,26 @@ void WMSelectTabViewItemAtIndex(WMTabView *tPtr, int index);
 void WMSetTabViewDelegate(WMTabView *tPtr, WMTabViewDelegate *delegate);
 
 
-WMTabViewItem *WMCreateTabViewItemWithIdentifier(int identifier);
+WMTabViewItem* WMCreateTabViewItemWithIdentifier(int identifier);
+
+void WMSetTabViewItemEnabled(WMTabViewItem *tPtr, Bool flag);
 
 int WMGetTabViewItemIdentifier(WMTabViewItem *item);
 
 void WMSetTabViewItemLabel(WMTabViewItem *item, char *label);
 
-char *WMGetTabViewItemLabel(WMTabViewItem *item);
+char* WMGetTabViewItemLabel(WMTabViewItem *item);
 
 void WMSetTabViewItemView(WMTabViewItem *item, WMView *view);
 
-WMView *WMGetTabViewItemView(WMTabViewItem *item);
+WMView* WMGetTabViewItemView(WMTabViewItem *item);
 
 void WMDestroyTabViewItem(WMTabViewItem *item);
 
 
 /* ....................................................................... */
 
-WMBox *WMCreateBox(WMWidget *parent);
+WMBox* WMCreateBox(WMWidget *parent);
 
 void WMSetBoxBorderWidth(WMBox *box, unsigned width);
 
@@ -1709,9 +1737,6 @@ void WMRemoveBoxSubview(WMBox *bPtr, WMView *view);
 
 void WMSetBoxHorizontal(WMBox *box, Bool flag);
 
-void WMSetBoxExpandsToParent(WMBox *box, int topOffs, int bottomOffs,
-                             int leftOffs, int rightOffs);
-
 /* ....................................................................... */
 
 int WMRunAlertPanel(WMScreen *app, WMWindow *owner, char *title, char *msg, 
@@ -1719,27 +1744,34 @@ int WMRunAlertPanel(WMScreen *app, WMWindow *owner, char *title, char *msg,
 		    char *otherButton);
 
 /* you can free the returned string */
-char *WMRunInputPanel(WMScreen *app, WMWindow *owner, char *title, char *msg,
+char* WMRunInputPanel(WMScreen *app, WMWindow *owner, char *title, char *msg,
 		      char *defaultText, char *okButton, char *cancelButton);
 
-WMAlertPanel *WMCreateAlertPanel(WMScreen *app, WMWindow *owner, char *title,
+WMAlertPanel* WMCreateAlertPanel(WMScreen *app, WMWindow *owner, char *title,
 				 char *msg, char *defaultButton, 
 				 char *alternateButton, char *otherButton);
 
-WMInputPanel *WMCreateInputPanel(WMScreen *app, WMWindow *owner, char *title,
+WMInputPanel* WMCreateInputPanel(WMScreen *app, WMWindow *owner, char *title,
 				 char *msg, char *defaultText, char *okButton, 
 				 char *cancelButton);
 
+
+WMGenericPanel* WMCreateGenericPanel(WMScreen *scrPtr, WMWindow *owner,
+				     char *title, char *defaultButton,
+				     char *alternateButton);
+
 void WMDestroyAlertPanel(WMAlertPanel *panel);
 
 void WMDestroyInputPanel(WMInputPanel *panel);
 
+void WMDestroyGenericPanel(WMGenericPanel *panel);
+
 /* ....................................................................... */
 
 /* only 1 instance per WMScreen */
-WMOpenPanel *WMGetOpenPanel(WMScreen *scrPtr);
+WMOpenPanel* WMGetOpenPanel(WMScreen *scrPtr);
 
-WMSavePanel *WMGetSavePanel(WMScreen *scrPtr);
+WMSavePanel* WMGetSavePanel(WMScreen *scrPtr);
 
 void WMSetFilePanelCanChooseDirectories(WMFilePanel *panel, Bool flag);
 
@@ -1750,7 +1782,7 @@ void WMSetFilePanelAutoCompletion(WMFilePanel *panel, Bool flag);
 void WMSetFilePanelDirectory(WMFilePanel *panel, char *path);
 
 /* you can free the returned string */
-char *WMGetFilePanelFileName(WMFilePanel *panel);
+char* WMGetFilePanelFileName(WMFilePanel *panel);
 
 void WMFreeFilePanel(WMFilePanel *panel);
 
@@ -1759,13 +1791,13 @@ int WMRunModalFilePanelForDirectory(WMFilePanel *panel, WMWindow *owner,
 
 void WMSetFilePanelAccessoryView(WMFilePanel *panel, WMView *view);
 
-WMView *WMGetFilePanelAccessoryView(WMFilePanel *panel);
+WMView* WMGetFilePanelAccessoryView(WMFilePanel *panel);
 
 
 /* ...................................................................... */
 
 /* only 1 instance per WMScreen */
-WMFontPanel *WMGetFontPanel(WMScreen *scr);
+WMFontPanel* WMGetFontPanel(WMScreen *scr);
 
 void WMShowFontPanel(WMFontPanel *panel);
 
@@ -1774,9 +1806,9 @@ void WMHideFontPanel(WMFontPanel *panel);
 void WMSetFontPanelFont(WMFontPanel *panel, WMFont *font);
 
 /* you can free the returned string */
-char *WMGetFontPanelFontName(WMFontPanel *panel);
+char* WMGetFontPanelFontName(WMFontPanel *panel);
 
-WMFont *WMGetFontPanelFont(WMFontPanel *panel);
+WMFont* WMGetFontPanelFont(WMFontPanel *panel);
 
 #ifdef __cplusplus
 }
